Index: mojo/edk/system/simple_broker.h |
diff --git a/mojo/edk/system/simple_token_serializer_win.h b/mojo/edk/system/simple_broker.h |
similarity index 57% |
rename from mojo/edk/system/simple_token_serializer_win.h |
rename to mojo/edk/system/simple_broker.h |
index 8e910f8b1489c745ba4eca5485e7a30f0649c05d..93b22f6942a95f173ee4bf51ce8718d5d5d4297a 100644 |
--- a/mojo/edk/system/simple_token_serializer_win.h |
+++ b/mojo/edk/system/simple_broker.h |
@@ -2,25 +2,25 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef MOJO_EDK_SYSTEM_SIMPLE_TOKEN_SERIALIZER_WIN_H_ |
-#define MOJO_EDK_SYSTEM_SIMPLE_TOKEN_SERIALIZER_WIN_H_ |
+#ifndef MOJO_EDK_SYSTEM_SIMPLE_BROKER_H_ |
+#define MOJO_EDK_SYSTEM_SIMPLE_BROKER_H_ |
-#include "mojo/edk/system/token_serializer_win.h" |
+#include "mojo/edk/system/broker.h" |
namespace mojo { |
namespace edk { |
// A simple implementation of TokenSerializer interface. This isn't meant for |
// production use (i.e. with multi-process, sandboxes). It's provided for use by |
// unittests. |
// Implementation note: this default implementation works across processes |
// without a sandbox. |
-class MOJO_SYSTEM_IMPL_EXPORT SimpleTokenSerializer : public TokenSerializer { |
+class MOJO_SYSTEM_IMPL_EXPORT SimpleBroker : public Broker { |
public: |
- SimpleTokenSerializer(); |
- ~SimpleTokenSerializer() override; |
+ SimpleBroker(); |
+ ~SimpleBroker() override; |
- // TokenSerializer implementation: |
+ // Broker implementation: |
+#if defined(OS_WIN) |
void CreatePlatformChannelPair(ScopedPlatformHandle* server, |
ScopedPlatformHandle* client) override; |
void HandleToToken(const PlatformHandle* platform_handles, |
@@ -29,9 +29,10 @@ class MOJO_SYSTEM_IMPL_EXPORT SimpleTokenSerializer : public TokenSerializer { |
void TokenToHandle(const uint64_t* tokens, |
size_t count, |
PlatformHandle* handles) override; |
+#endif |
}; |
} // namespace edk |
} // namespace mojo |
-#endif // MOJO_EDK_SYSTEM_SIMPLE_TOKEN_SERIALIZER_WIN_H_ |
+#endif // MOJO_EDK_SYSTEM_SIMPLE_BROKER_H_ |
@@ -2,25 +2,25 @@ |
namespace mojo { |
namespace edk { |
-// A simple implementation of TokenSerializer interface. This isn't meant for |
-// production use (i.e. with multi-process, sandboxes). It's provided for use by |
-// unittests. |
+// A simple implementation of Broker interface. This isn't meant for production |
+// use (i.e. with multi-process, sandboxes). It's provided for use by unittests. |
// Implementation note: this default implementation works across processes |
// without a sandbox. |